@@ -3,7 +3,7 @@ use serde::{Deserialize, Serialize};
 use std::fmt;
 use zeroize::Zeroize;
 
-#[derive(Debug, PartialEq, Eq, Serialize, Deserialize, Zeroize)]
+#[derive(Debug, PartialEq, Eq, Serialize, Deserialize, Zeroize, Clone)]
 #[zeroize(drop)]
 pub enum SecretStoreError {
   Locked,
